import { SupportedLanguagesEnum } from '@energyweb/origin-ui-localization';
import { useTranslation } from 'react-i18next';
import * as Yup from 'yup';
import { showNotification, NotificationTypeEnum, VisibilityButton } from '@energyweb/origin-ui-core';
import { useWeb3, MetamaskAdapter, NotAllowedChainIdError } from '@energyweb/origin-ui-web3';
import { useNavigate } from 'react-router';
import React from 'react';
import { UserStatus, KYCStatus, OrganizationStatus as OrganizationStatus$1 } from '@energyweb/origin-backend-react-query-client';
import { PowerFormatter, formatDate, EnergyFormatter } from '@energyweb/origin-ui-utils';
import { OrganizationStatus, Role, KYCStatus as KYCStatus$1, UserStatus as UserStatus$1 } from '@energyweb/origin-backend-core';
import { Countries, IRECBusinessLegalStatusLabelsMap } from '@energyweb/utils-general';
import { HowToReg, AccountCircle, ExitToApp } from '@mui/icons-material';

const prepareLanguageOptions = t => {
  const supportedLanugages = Object.keys(SupportedLanguagesEnum);
  return supportedLanugages.map(language => ({
    label: t(`user.settings.languages.${language}`),
    value: language
  }));
};

const useSettingsPageLogic = () => {
  const {
    t
  } = useTranslation();
  return {
    notificationsLabel: t('user.settings.notifications'),
    languageLabel: t('user.settings.language'),
    languageOptions: prepareLanguageOptions(t),
    buttonText: t('general.buttons.update')
  };
};

const useOrganizationBlockchainAddressLogic = () => {
  const {
    t
  } = useTranslation();
  return {
    title: t('user.profile.orgBlockchainAccountAddress'),
    popoverText: [t('user.profile.popover.blockchainWhatIs'), t('user.profile.popover.blockchainWhatFor'), t('user.profile.popover.blockchainHowTo')],
    buttonText: t('user.profile.connectBlockchain')
  };
};

const useExchangeDepositAddressLogic = () => {
  const {
    t
  } = useTranslation();
  return {
    title: t('user.profile.exchangeAddressTitle'),
    popoverText: [t('user.profile.popover.exchangeAddressWhatFor'), t('user.profile.popover.exchangeAddressHowTo')]
  };
};

const useUpdateUserAccountDataFormConfig = user => {
  const {
    t
  } = useTranslation();
  const {
    firstName,
    lastName,
    telephone,
    status,
    kycStatus,
    emailConfirmed
  } = user;
  const initialFormData = {
    firstName,
    lastName,
    telephone,
    status,
    kycStatus,
    emailConfirmed: emailConfirmed ? t('user.profile.yes') : t('user.profile.no')
  };
  return {
    buttonText: t('general.buttons.edit'),
    fields: [{
      label: t('user.profile.firstName'),
      name: 'firstName',
      required: true,
      inputProps: {
        ['data-cy']: 'firstName'
      }
    }, {
      label: t('user.profile.lastName'),
      name: 'lastName',
      required: true,
      inputProps: {
        ['data-cy']: 'lastName'
      }
    }, {
      label: t('user.profile.telephone'),
      name: 'telephone',
      required: true,
      inputProps: {
        ['data-cy']: 'telephone'
      }
    }, {
      label: t('user.profile.status'),
      name: 'status',
      textFieldProps: {
        disabled: true
      },
      inputProps: {
        ['data-cy']: 'status'
      }
    }, {
      label: t('user.profile.kycStatus'),
      name: 'kycStatus',
      textFieldProps: {
        disabled: true
      }
    }, {
      label: t('user.profile.emailConfirmed'),
      name: 'emailConfirmed',
      textFieldProps: {
        disabled: true
      }
    }],
    buttonWrapperProps: {
      justifyContent: 'flex-start'
    },
    buttonProps: {
      ['data-cy']: 'user-data-change-button'
    },
    initialValues: initialFormData,
    twoColumns: true,
    inputsVariant: 'filled',
    validationSchema: Yup.object().shape({
      firstName: Yup.string().label(t('user.profile.firstName')).required(),
      lastName: Yup.string().label(t('user.profile.lastName')).required(),
      telephone: Yup.string().required().min(10).label(t('user.profile.telephone'))
    })
  };
};

const useUpdateUserAccountEmailFormConfig = initialValues => {
  const {
    t
  } = useTranslation();
  return {
    buttonText: t('general.buttons.change'),
    fields: [{
      label: t('user.profile.email'),
      name: 'email',
      required: true,
      inputProps: {
        ['data-cy']: 'email'
      }
    }],
    buttonWrapperProps: {
      justifyContent: 'flex-start'
    },
    buttonProps: {
      ['data-cy']: 'email-change-button'
    },
    initialValues: {
      email: initialValues === null || initialValues === void 0 ? void 0 : initialValues.email
    },
    inputsVariant: 'filled',
    validationSchema: Yup.object().shape({
      email: Yup.string().email().label(t('user.profile.email')).required()
    })
  };
};

const INITIAL_FORM_VALUES$2 = {
  oldPassword: '',
  newPassword: '',
  newPasswordConfirm: ''
};
const useUpdateUserAccountPasswordFormConfig = () => {
  const {
    t
  } = useTranslation();
  return {
    buttonText: t('general.buttons.change'),
    fields: [{
      type: 'password',
      label: t('user.profile.currentPassword'),
      name: 'oldPassword',
      required: true,
      inputProps: {
        ['data-cy']: 'oldPassword'
      }
    }, {
      type: 'password',
      label: t('user.profile.newPassword'),
      name: 'newPassword',
      required: true,
      inputProps: {
        ['data-cy']: 'newPassword'
      }
    }, {
      type: 'password',
      label: t('user.profile.newPasswordConfirm'),
      name: 'newPasswordConfirm',
      required: true,
      inputProps: {
        ['data-cy']: 'newPasswordConfirm'
      }
    }],
    buttonWrapperProps: {
      justifyContent: 'flex-start'
    },
    buttonProps: {
      ['data-cy']: 'password-change-button'
    },
    initialValues: INITIAL_FORM_VALUES$2,
    inputsVariant: 'filled',
    validationSchema: Yup.object().shape({
      oldPassword: Yup.string().label(t('user.profile.currentPassword')).required(),
      newPassword: Yup.string().label(t('user.profile.newPassword')).required(),
      newPasswordConfirm: Yup.string().oneOf([Yup.ref('newPassword'), null], t('user.profile.confirmDoesntMatch')).label(t('user.profile.newPasswordConfirm')).required()
    })
  };
};

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

function __awaiter(thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
}

const useConnectMetamaskPlaceholderLogic = allowedChainIds => {
  const {
    t
  } = useTranslation();
  const {
    connect
  } = useWeb3();

  const handleInstall = () => {
    window.location.replace('https://metamask.io/');
  };

  const handleError = error => {
    if (error instanceof NotAllowedChainIdError) {
      showNotification(t('metamask.notifications.unsupportedNetwork'), NotificationTypeEnum.Error);
    } else {
      showNotification(t('metamask.notifications.unknownError'), NotificationTypeEnum.Error);
    }
  };

  const handleConnect = () => __awaiter(void 0, void 0, void 0, function* () {
    yield connect(new MetamaskAdapter(allowedChainIds, handleError));
  });

  const noMetamaskInstalled = !(window.web3 || window.ethereum);
  const clickHandler = noMetamaskInstalled ? handleInstall : handleConnect;
  const buttonText = noMetamaskInstalled ? t('metamask.installMetamask') : t('metamask.connectMetamask');
  const title = t('metamask.blockRequireInstalledAndConnected');
  return {
    clickHandler,
    buttonText,
    title
  };
};

const INITIAL_FORM_VALUES$1 = {
  username: '',
  password: ''
};
const useUserLogInFormConfig = formSubmitHandler => {
  const {
    t
  } = useTranslation();
  return {
    buttonFullWidth: true,
    buttonText: t('user.login.loginButton'),
    fields: [{
      label: t('user.login.email'),
      name: 'username',
      required: true,
      inputProps: {
        ['data-cy']: 'email'
      }
    }, {
      label: t('user.login.password'),
      type: 'password',
      name: 'password',
      required: true,
      inputProps: {
        ['data-cy']: 'password'
      }
    }],
    buttonProps: {
      ['data-cy']: 'login-button'
    },
    buttonWrapperProps: {
      justifyContent: 'flex-start'
    },
    initialValues: INITIAL_FORM_VALUES$1,
    submitHandler: formSubmitHandler,
    validationMode: 'onTouched',
    inputsVariant: 'filled',
    validationSchema: Yup.object().shape({})
  };
};

const INITIAL_FORM_VALUES = {
  title: '',
  firstName: '',
  lastName: '',
  telephone: '',
  email: '',
  password: ''
};
const TITLES = ['Dr', 'Mr', 'Mrs', 'Ms', 'Other'];
const useUserSignInFormConfig = formSubmitHandler => {
  const {
    t
  } = useTranslation();
  const TITLE_OPTIONS = TITLES.map(title => ({
    label: t(`general.titles.${title.toLowerCase()}`),
    value: title
  }));
  return {
    buttonText: t('general.buttons.register'),
    validationMode: 'onSubmit',
    fields: [{
      label: t('user.register.title'),
      name: 'title',
      select: true,
      options: TITLE_OPTIONS,
      required: true,
      inputProps: {
        ['data-cy']: 'register-title-select'
      },
      additionalInputProps: {
        valueToOpen: 'Other',
        name: 'titleInput',
        label: t('user.register.title'),
        required: true,
        inputProps: {
          ['data-cy']: 'register-other-title-input'
        }
      }
    }, {
      label: t('user.register.firstName'),
      name: 'firstName',
      required: true,
      inputProps: {
        ['data-cy']: 'firstName'
      }
    }, {
      label: t('user.register.lastName'),
      name: 'lastName',
      required: true,
      inputProps: {
        ['data-cy']: 'lastName'
      }
    }, {
      label: t('user.register.email'),
      name: 'email',
      required: true,
      inputProps: {
        ['data-cy']: 'email'
      }
    }, {
      label: t('user.register.telephone'),
      name: 'telephone',
      required: true,
      inputProps: {
        ['data-cy']: 'telephone'
      }
    }, {
      type: 'password',
      label: t('user.register.password'),
      name: 'password',
      required: true,
      inputProps: {
        ['data-cy']: 'password'
      }
    }],
    twoColumns: true,
    buttonWrapperProps: {
      justifyContent: 'flex-start'
    },
    buttonProps: {
      ['data-cy']: 'register-button'
    },
    initialValues: INITIAL_FORM_VALUES,
    submitHandler: formSubmitHandler,
    inputsVariant: 'filled',
    validationSchema: Yup.object().shape({
      title: Yup.string().label(t('user.register.title')).required(),
      firstName: Yup.string().label(t('user.register.firstName')).required(),
      lastName: Yup.string().label(t('user.register.lastName')).required(),
      email: Yup.string().email().label(t('user.register.email')).required(),
      telephone: Yup.string().required().min(10).label(t('user.register.telephone')),
      password: Yup.string().required().matches(/((?=.*[0-9])(?=.*[a-z]).{6,})/, t('user.register.passwordValidation')).label(t('user.register.password'))
    })
  };
};

const useRequestResetPasswordFormLogic = isMutating => {
  const {
    t
  } = useTranslation();
  const navigate = useNavigate();
  return {
    formTitle: t('user.requestResetPassword.formTitle'),
    formTitleVariant: 'h6',
    loading: isMutating,
    initialValues: {
      email: ''
    },
    validationSchema: Yup.object().shape({
      email: Yup.string().email().label(t('user.requestResetPassword.email')).required()
    }),
    fields: [{
      name: 'email',
      label: t('user.requestResetPassword.email'),
      required: true
    }],
    secondaryButtons: [{
      label: t('general.buttons.back'),
      onClick: () => navigate('/login'),
      variant: 'outlined'
    }],
    inputsVariant: 'filled',
    validationMode: 'onSubmit',
    buttonWrapperProps: {
      display: 'flex',
      justifyContent: 'space-between'
    },
    buttonText: t('general.buttons.submit')
  };
};

const useResetPasswordFormLogic = ({
  passwordVisible,
  setPasswordVisible,
  passwordConfirmVisible,
  setPasswordConfirmVisible,
  isMutating
}) => {
  const {
    t
  } = useTranslation();
  return {
    formTitle: t('user.resetPassword.formTitle'),
    formTitleVariant: 'h6',
    initialValues: {
      password: '',
      passwordConfirm: ''
    },
    loading: isMutating,
    validationMode: 'onBlur',
    validationSchema: Yup.object().shape({
      password: Yup.string().matches(/((?=.*[0-9])(?=.*[a-z]).{6,})/, t('user.register.passwordValidation')).label(t('user.resetPassword.newPassword')).required(),
      passwordConfirm: Yup.string().required().oneOf([Yup.ref('password'), null], t('general.validations.passwordMatch')).label(t('user.resetPassword.passwordConfirm'))
    }),
    fields: [{
      label: t('user.resetPassword.newPassword'),
      name: 'password',
      required: true,
      type: passwordVisible ? 'text' : 'password',
      endAdornment: {
        element: /*#__PURE__*/React.createElement(VisibilityButton, {
          visible: passwordVisible,
          setVisible: setPasswordVisible
        })
      }
    }, {
      label: t('user.resetPassword.passwordConfirm'),
      name: 'passwordConfirm',
      required: true,
      type: passwordConfirmVisible ? 'text' : 'password',
      endAdornment: {
        element: /*#__PURE__*/React.createElement(VisibilityButton, {
          visible: passwordConfirmVisible,
          setVisible: setPasswordConfirmVisible
        })
      }
    }],
    inputsVariant: 'filled',
    buttonText: t('general.buttons.submit')
  };
};

const prepareUsersData = (user, actions) => {
  var _a;

  return {
    id: user.id,
    name: `${user.firstName} ${user.lastName}`,
    organization: (_a = user.organization) === null || _a === void 0 ? void 0 : _a.name,
    email: user.email,
    status: user.status,
    kycStatus: user.kycStatus,
    actions: actions
  };
};

const useAdminUsersTableLogic = (users, actions, loading) => {
  var _a;

  const {
    t
  } = useTranslation();
  return {
    header: {
      name: t('admin.users.name'),
      organization: t('admin.users.organization'),
      email: t('admin.users.email'),
      status: t('admin.users.status'),
      kycStatus: t('admin.users.kycStatus'),
      actions: ''
    },
    loading,
    pageSize: 25,
    data: (_a = users === null || users === void 0 ? void 0 : users.map(user => prepareUsersData(user, actions))) !== null && _a !== void 0 ? _a : []
  };
};

const STATUS_OPTIONS = Object.keys(UserStatus).map(key => ({
  value: key,
  label: key
}));
const KYC_STATUS_OPTIONS = Object.keys(KYCStatus).map(key => ({
  value: key,
  label: key
}));

const useAdminUpdateUserFormLogic = user => {
  const {
    t
  } = useTranslation();
  const initialFormData = {
    title: user === null || user === void 0 ? void 0 : user.title,
    firstName: user === null || user === void 0 ? void 0 : user.firstName,
    lastName: user === null || user === void 0 ? void 0 : user.lastName,
    email: user === null || user === void 0 ? void 0 : user.email,
    telephone: user === null || user === void 0 ? void 0 : user.telephone,
    status: user === null || user === void 0 ? void 0 : user.status,
    kycStatus: user === null || user === void 0 ? void 0 : user.kycStatus
  };
  return {
    buttonText: t('general.buttons.update'),
    fields: [{
      label: t('admin.updateUser.title'),
      name: 'title'
    }, {
      label: t('admin.updateUser.firstName'),
      name: 'firstName'
    }, {
      label: t('admin.updateUser.lastName'),
      name: 'lastName'
    }, {
      label: t('admin.updateUser.email'),
      name: 'email'
    }, {
      label: t('admin.updateUser.telephone'),
      name: 'telephone'
    }, {
      label: t('admin.updateUser.status'),
      name: 'status',
      select: true,
      options: STATUS_OPTIONS
    }, {
      label: t('admin.updateUser.kycStatus'),
      name: 'kycStatus',
      select: true,
      options: KYC_STATUS_OPTIONS
    }],
    buttonWrapperProps: {
      justifyContent: 'flex-start'
    },
    initialValues: initialFormData,
    twoColumns: true,
    inputsVariant: 'filled',
    validationSchema: Yup.object().shape({
      firstName: Yup.string().label(t('admin.updateUser.firstName')).required(),
      lastName: Yup.string().label(t('admin.updateUser.lastName')).required(),
      email: Yup.string().email().label(t('admin.updateUser.email')).required(),
      telephone: Yup.string().label(t('admin.updateUser.telephone')).required()
    })
  };
};

const formatClaims = ({
  certificates,
  allDevices
}) => {
  const formattedClaims = [];
  certificates === null || certificates === void 0 ? void 0 : certificates.forEach(certificate => {
    var _a;

    return (_a = certificate.claims) === null || _a === void 0 ? void 0 : _a.forEach(claim => {
      var _a;

      formattedClaims.push({
        id: `${certificate.id};${claim.claimData.periodStartDate}`,
        certificateId: certificate.id,
        deviceName: (_a = allDevices.find(device => device.externalRegistryId === certificate.deviceId)) === null || _a === void 0 ? void 0 : _a.name,
        energy: PowerFormatter.format(parseInt(claim.value), true),
        beneficiary: claim.claimData.beneficiary,
        fromDate: formatDate(claim.claimData.periodStartDate),
        toDate: formatDate(claim.claimData.periodEndDate)
      });
    });
  });
  return formattedClaims;
};

const useClaimsTableLogic = ({
  isLoading,
  certificates,
  allDevices
}) => {
  const {
    t
  } = useTranslation();
  return {
    header: {
      certificateId: t('admin.claims.certificateId'),
      deviceName: t('admin.claims.deviceName'),
      energy: t('admin.claims.energy'),
      beneficiary: t('admin.claims.beneficiary'),
      fromDate: t('admin.claims.fromDate'),
      toDate: t('admin.claims.toDate')
    },
    pageSize: 10,
    loading: isLoading,
    data: formatClaims({
      certificates,
      allDevices
    })
  };
};

const formatTrades = ({
  trades
}) => {
  return (trades === null || trades === void 0 ? void 0 : trades.map(trade => {
    const price = trade.price / 100;
    const totalPrice = parseFloat(EnergyFormatter.format(trade.volume)) * price;
    return {
      id: trade.id,
      dateAndTime: formatDate(trade.created, true),
      buyerId: trade.bidUserId,
      sellerId: trade.askUserId,
      volume: EnergyFormatter.format(trade.volume),
      certificateId: trade.tokenId,
      price,
      total: `$${totalPrice.toFixed(2)}`
    };
  })) || [];
};

const useTradesTableLogic = ({
  trades,
  loading
}) => {
  const {
    t
  } = useTranslation();
  return {
    header: {
      dateAndTime: t('admin.trades.dateAndTime'),
      buyerId: t('admin.trades.buyerId'),
      sellerId: t('admin.trades.sellerId'),
      certificateId: t('admin.trades.certificateId'),
      volume: `${t('admin.trades.volume')} (${EnergyFormatter.displayUnit})`,
      price: t('admin.trades.price'),
      total: t('admin.trades.total')
    },
    pageSize: 10,
    loading,
    data: formatTrades({
      trades
    })
  };
};

const formatOrganizations = ({
  allOrganizations,
  actions
}) => {
  return allOrganizations === null || allOrganizations === void 0 ? void 0 : allOrganizations.map(org => {
    var _a;

    return {
      id: org.id,
      name: org.name,
      country: (_a = Countries.find(country => country.code === org.country)) === null || _a === void 0 ? void 0 : _a.name,
      tradeRegistryNumber: org.tradeRegistryCompanyNumber,
      status: org.status,
      actions: org.status === OrganizationStatus.Submitted ? actions : undefined
    };
  });
};

const useAllOrganizationsTableLogic = ({
  allOrganizations,
  actions,
  isLoading
}) => {
  var _a;

  const {
    t
  } = useTranslation();
  const navigate = useNavigate();
  return {
    header: {
      name: t('organization.all.name'),
      country: t('organization.all.country'),
      tradeRegistryNumber: t('organization.all.tradeRegistryNumber'),
      status: t('organization.all.status'),
      actions: ''
    },
    onRowClick: id => navigate(`/admin/organization/${id}`),
    pageSize: 20,
    loading: isLoading,
    data: (_a = formatOrganizations({
      allOrganizations,
      actions
    })) !== null && _a !== void 0 ? _a : []
  };
};

const useAdminOrganizationViewLogic = organization => {
  var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m;

  const {
    t
  } = useTranslation();
  return {
    orgFormData: {
      heading: t('organization.view.regular.title'),
      data: [{
        label: t('organization.view.regular.name'),
        value: (_a = organization === null || organization === void 0 ? void 0 : organization.name) !== null && _a !== void 0 ? _a : ''
      }, {
        label: t('organization.view.regular.address'),
        value: (_b = organization === null || organization === void 0 ? void 0 : organization.address) !== null && _b !== void 0 ? _b : ''
      }, {
        label: t('organization.view.regular.businessType'),
        value: formatOrganizationBusinessType((_c = organization === null || organization === void 0 ? void 0 : organization.businessType) !== null && _c !== void 0 ? _c : '')
      }, {
        label: t('organization.view.regular.tradeRegistry'),
        value: (_d = organization === null || organization === void 0 ? void 0 : organization.tradeRegistryCompanyNumber) !== null && _d !== void 0 ? _d : ''
      }, {
        label: t('organization.view.regular.vat'),
        value: (_e = organization === null || organization === void 0 ? void 0 : organization.tradeRegistryCompanyNumber) !== null && _e !== void 0 ? _e : ''
      }, {
        label: t('organization.view.regular.signatoryName'),
        value: (_f = organization === null || organization === void 0 ? void 0 : organization.signatoryFullName) !== null && _f !== void 0 ? _f : ''
      }, {
        label: t('organization.view.regular.signatoryAddress'),
        value: (_g = organization === null || organization === void 0 ? void 0 : organization.signatoryAddress) !== null && _g !== void 0 ? _g : ''
      }, {
        label: t('organization.view.regular.signatoryEmail'),
        value: (_h = organization === null || organization === void 0 ? void 0 : organization.signatoryEmail) !== null && _h !== void 0 ? _h : ''
      }, {
        label: t('organization.view.regular.signatoryPhone'),
        value: (_j = organization === null || organization === void 0 ? void 0 : organization.signatoryPhoneNumber) !== null && _j !== void 0 ? _j : ''
      }, {
        label: t('organization.view.regular.status'),
        value: (_k = organization === null || organization === void 0 ? void 0 : organization.status) !== null && _k !== void 0 ? _k : ''
      }]
    },
    docsBlockHeading: t('organization.view.regular.documents'),
    companyProofData: {
      documents: (_l = organization === null || organization === void 0 ? void 0 : organization.documentIds) !== null && _l !== void 0 ? _l : [''],
      blockTitle: t('organization.view.regular.companyProof')
    },
    signatoryData: {
      documents: (_m = organization === null || organization === void 0 ? void 0 : organization.signatoryDocumentIds) !== null && _m !== void 0 ? _m : [''],
      blockTitle: t('organization.view.regular.signatoryId')
    }
  };
};
const formatOrganizationBusinessType = businessType => {
  if (!businessType) return '';
  return IRECBusinessLegalStatusLabelsMap[businessType];
};

const getAccountMenu = ({
  t,
  isOpen,
  showSettings,
  showUserProfile,
  selectedMenuItemClass,
  menuButtonClass
}) => ({
  isOpen,
  dataCy: 'settingsMenu',
  sectionTitle: showUserProfile ? t('navigation.account.sectionTitle') : t('navigation.account.sectionTitleForUnlogged'),
  rootUrl: '/account',
  show: true,
  menuList: [{
    url: 'settings',
    label: t('navigation.account.settings'),
    show: showSettings,
    dataCy: 'accountSettings'
  }, {
    url: 'profile',
    label: t('navigation.account.userProfile'),
    show: showUserProfile,
    dataCy: 'accountUserProfile'
  }],
  menuButtonClass,
  selectedMenuItemClass
});

const getAdminMenu = ({
  t,
  isOpen,
  showSection,
  showUsers,
  showAllOrgs,
  showClaims,
  showTrades,
  menuButtonClass,
  selectedMenuItemClass
}) => {
  return {
    isOpen,
    dataCy: 'adminMenu',
    sectionTitle: t('navigation.admin.sectionTitle'),
    rootUrl: '/admin',
    show: showSection,
    menuList: [{
      url: 'users',
      label: t('navigation.admin.users'),
      show: showUsers,
      dataCy: 'adminUsers'
    }, {
      url: 'organizations',
      label: t('navigation.admin.organizations'),
      show: showAllOrgs,
      dataCy: 'adminOrganizations'
    }, {
      url: 'claims',
      label: t('navigation.admin.claims'),
      show: showClaims,
      dataCy: 'adminClaims'
    }, {
      url: 'trades',
      label: t('navigation.admin.trades'),
      show: showTrades,
      dataCy: 'adminTrades'
    }],
    menuButtonClass,
    selectedMenuItemClass
  };
};

const useUserRegisteredModalLogic = closeModal => {
  const {
    t
  } = useTranslation();
  return {
    title: t('user.modals.userRegistered.title'),
    text: t('user.modals.userRegistered.text'),
    buttons: [{
      label: t('general.buttons.ok'),
      onClick: closeModal,
      ['data-cy']: 'user-registered-modal-ok'
    }]
  };
};

const useLoginRegisterOrgModalLogic = (closeModal, navigateToRegister) => {
  const {
    t
  } = useTranslation();
  return {
    title: t('user.modals.loginRegisterOrg.title'),
    text: t('user.modals.loginRegisterOrg.text'),
    buttons: [{
      label: t('general.buttons.notNow'),
      onClick: closeModal
    }, {
      label: t('user.modals.loginRegisterOrg.registerOrgButton'),
      onClick: navigateToRegister
    }]
  };
};

const roleNames = [{
  value: Role.OrganizationAdmin,
  label: 'user.modals.roleOrgAdmin'
}, {
  value: Role.OrganizationDeviceManager,
  label: 'user.modals.roleOrgDeviceManager'
}, {
  value: Role.OrganizationUser,
  label: 'user.modals.roleOrgMember'
}];
const usePendingInvitationModalLogic = ({
  invitation,
  acceptHandler,
  declineHandler,
  laterHandler
}) => {
  var _a;

  const {
    t
  } = useTranslation();
  return {
    title: t('user.modals.pendingInvitation.title'),
    text: t('user.modals.pendingInvitation.text', {
      admin: invitation === null || invitation === void 0 ? void 0 : invitation.sender,
      role: t((_a = roleNames.find(role => role.value === (invitation === null || invitation === void 0 ? void 0 : invitation.role))) === null || _a === void 0 ? void 0 : _a.label),
      orgName: invitation === null || invitation === void 0 ? void 0 : invitation.organization.name
    }),
    buttons: [{
      label: t('general.buttons.later'),
      onClick: () => laterHandler(invitation.id)
    }, {
      label: t('general.buttons.decline'),
      onClick: () => declineHandler(invitation.id)
    }, {
      label: t('general.buttons.accept'),
      onClick: () => acceptHandler(invitation.id)
    }]
  };
};

const useCreateExchangeAddressModalLogic = (closeModal, navigateToCreate) => {
  const {
    t
  } = useTranslation();
  return {
    title: t('user.modals.createExchangeAddress.title'),
    text: t('user.modals.createExchangeAddress.text'),
    buttons: [{
      label: t('general.buttons.notNow'),
      onClick: closeModal
    }, {
      label: t('user.modals.createExchangeAddress.create'),
      onClick: navigateToCreate
    }]
  };
};

const getRoleChangedLogic = ({
  t,
  closeModal,
  role,
  orgName,
  isIRecEnabled
}) => {
  const memberActions = isMainRole => ({
    title: isMainRole ? t('organization.modals.roleChanged.asMemberYouCan') : t('organization.modals.roleChanged.asAMemberYouCanAlso'),
    actions: [t('organization.modals.roleChanged.canPlaceOrder'), t('organization.modals.roleChanged.canBuyCertificates', {
      certificateType: isIRecEnabled ? 'I-RECs' : 'certificates'
    }), t('organization.modals.roleChanged.canCreateAndBuyCertificateBundles', {
      certificateType: isIRecEnabled ? 'I-REC' : 'certificate'
    }), t('organization.modals.roleChanged.canRedeemCertificates', {
      certificateType: isIRecEnabled ? 'I-RECs' : 'certificates'
    }), t('organization.modals.roleChanged.canWithdrawCertificates', {
      certificateType: isIRecEnabled ? 'I-RECs' : 'certificates'
    })]
  });

  const deviceManagerActions = isMainRole => ({
    title: isMainRole ? t('organization.modals.roleChanged.asDeviceManagerYouCan') : t('organization.modals.roleChanged.asDeviceManagerYouCanAlso'),
    actions: [t('organization.modals.roleChanged.canRegisterDevices'), t('organization.modals.roleChanged.canRequestIssuenceOfCertificates', {
      certificateType: isIRecEnabled ? 'I-RECs' : 'certificates'
    }), t('organization.modals.roleChanged.canConfigureAutomatedOrderCreation')]
  });

  const orgAdminActions = {
    title: t('organization.modals.roleChanged.asOrgAdminYouCan'),
    actions: [t('organization.modals.roleChanged.canAddOrRemoveOrgMembers'), t('organization.modals.roleChanged.canEditUserRoles'), isIRecEnabled && t('organization.modals.roleChanged.connectOrgToIRec')]
  };
  const roleDescriptions = role === Role.OrganizationUser ? [memberActions(true)] : role === Role.OrganizationDeviceManager ? [deviceManagerActions(true), memberActions(false)] : role === Role.OrganizationAdmin ? [orgAdminActions, deviceManagerActions(false), memberActions(false)] : [];
  return {
    title: t('organization.modals.roleChanged.title', {
      organizationName: orgName
    }),
    subtitle: t('organization.modals.roleChanged.text', {
      organizationName: orgName
    }),
    roleDescriptions,
    buttons: [{
      label: 'Ok',
      onClick: closeModal
    }]
  };
};

const getTopbarButtonList = (isAuthenticated, onLogout, t, navigate) => {
  return [{
    label: t('navigation.topbar.register'),
    show: !isAuthenticated,
    onClick: () => {
      navigate('/auth/register');
    },
    Icon: HowToReg,
    dataCy: 'navigation-register-button'
  }, {
    label: t('navigation.topbar.login'),
    show: !isAuthenticated,
    onClick: () => {
      navigate('/login');
    },
    Icon: AccountCircle,
    dataCy: 'navigation-login-button'
  }, {
    label: t('navigation.topbar.logout'),
    show: isAuthenticated,
    onClick: onLogout,
    Icon: ExitToApp,
    dataCy: 'navigation-logout-button'
  }];
};

const useUserAndOrgData = user => {
  var _a;

  const {
    t
  } = useTranslation();
  return {
    userData: {
      username: `${user === null || user === void 0 ? void 0 : user.firstName} ${user === null || user === void 0 ? void 0 : user.lastName}`,
      userPending: (user === null || user === void 0 ? void 0 : user.kycStatus) === KYCStatus$1.Pending || (user === null || user === void 0 ? void 0 : user.status) === UserStatus$1.Pending,
      userTooltip: t('navigation.layout.userPendingTooltip')
    },
    orgData: {
      orgName: (_a = user === null || user === void 0 ? void 0 : user.organization) === null || _a === void 0 ? void 0 : _a.name,
      orgPending: (user === null || user === void 0 ? void 0 : user.organization) && user.organization.status !== OrganizationStatus$1.Active,
      orgTooltip: t('navigation.layout.orgPendingTooltip')
    }
  };
};

export { INITIAL_FORM_VALUES$1 as INITIAL_FORM_VALUES, formatOrganizationBusinessType, getAccountMenu, getAdminMenu, getRoleChangedLogic, getTopbarButtonList, roleNames, useAdminOrganizationViewLogic, useAdminUpdateUserFormLogic, useAdminUsersTableLogic, useAllOrganizationsTableLogic, useClaimsTableLogic, useConnectMetamaskPlaceholderLogic, useCreateExchangeAddressModalLogic, useExchangeDepositAddressLogic, useLoginRegisterOrgModalLogic, useOrganizationBlockchainAddressLogic, usePendingInvitationModalLogic, useRequestResetPasswordFormLogic, useResetPasswordFormLogic, useSettingsPageLogic, useTradesTableLogic, useUpdateUserAccountDataFormConfig, useUpdateUserAccountEmailFormConfig, useUpdateUserAccountPasswordFormConfig, useUserAndOrgData, useUserLogInFormConfig, useUserRegisteredModalLogic, useUserSignInFormConfig };
